;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "org-mcp" "20260708.1210"
  "MCP server for Org-mode."
  '((emacs          "28.2")
    (mcp-server-lib "0.4.0"))
  :url "https://github.com/laurynas-biveinis/org-mcp"
  :commit "d14b914f5c29645c5321259cb772beddae96c2e2"
  :revdesc "d14b914f5c29"
  :keywords '("convenience" "files" "matching" "outlines")
  :authors '(("Laurynas Biveinis" . "laurynas.biveinis@gmail.com"))
  :maintainers '(("Laurynas Biveinis" . "laurynas.biveinis@gmail.com")))
